@@ -2,9 +2,10 @@
 
 var word = require('./word'),
     ast = require('./ast'),
-    estraverse = require('estraverse');
+    // estraverse = require('estraverse'),
+    colors = require('colors/safe');
 
-var Syntax = estraverse.Syntax;
+// var Syntax = estraverse.Syntax;
 
 function interpret (str, done) {
     var w, wordLink, num, lines;
@@ -32,7 +33,7 @@ function interpret (str, done) {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
                     lines = this.io.buf.slice(0, this.io.ptr).split('\n');
-                    console.log('Error in line: %s', lines.length - 1);
+                    console.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
                     console.log('word: ' + w + ' is not defined');
                     console.log(lines.pop());
                     throw new Error;
@@ -47,7 +48,7 @@ function interpret (str, done) {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
                     lines = this.io.buf.slice(0, this.io.ptr).split('\n');
-                    console.log('Error in line: %s', lines.length - 1);
+                    console.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
                     console.log('word: ' + w + ' is not defined');
                     console.log(lines.pop());
                     throw new Error;
